@@ -12,6 +12,7 @@ from lsystem.core.lsystem_utils import (
     get_saved_lsystem,
     generate_lsystem_2d,
     generate_lsystem_3d,
+    remove_saved_lsystem,
 )
 from PyQt5.QtGui import QIcon
 from lsystem.core.input_check import input_check
@@ -179,7 +180,7 @@ class UIWidget(QWidget):
 
         self.prod_percent.append(CustomLineEdit())
         self.prod_percent[0].setFixedWidth(50)
-        self.prod_percent[0].setText("1")
+        self.prod_percent[0].setText("100%")
 
         self.text_boxes.append(self.prod_percent[-1])
         self.angle_edit.returnPressed.connect(self.lsys_button.click)
@@ -216,6 +217,8 @@ class UIWidget(QWidget):
               self.examples[i].setIconSize(QtCore.QSize(120, 100))
             else:
               self.examples[i].setText(key)
+              self.examples[i].setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+              self.examples[i].customContextMenuRequested.connect(lambda state, x=key: self.del_example(str(x), "two-d"))
             self.examples[i].clicked.connect(
                 lambda state, x=key: self.gen_example(str(x))
             )
@@ -239,6 +242,8 @@ class UIWidget(QWidget):
                   self.examples[i].setIcon(QIcon('{}/lsystem/assets/images/{}.png'.format(os.getcwd(), self.precons[i])))
                   self.examples[i].setIconSize(QtCore.QSize(120, 100))
                 else:
+                  self.examples[i].setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+                  self.examples[i].customContextMenuRequested.connect(lambda state, x=key: self.del_example(str(x),"two-d"))
                   self.examples[i].setText(key)
                 self.examples[i].clicked.connect(
                     lambda state, x=key: self.gen_example(str(x))
@@ -257,6 +262,9 @@ class UIWidget(QWidget):
                     lambda state, x=key: self.gen_example(str(x))
                 )
                 self.layout_examples.addWidget(self.examples[i])
+                if(i>1): # TODO - This is temporary until we have a manner of separting 3d precons from 2d precons
+                  self.examples[i].setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+                  self.examples[i].customContextMenuRequested.connect(lambda state, x=key: self.del_example(str(x),"three-d"))
 
 
     @QtCore.pyqtSlot()
@@ -461,7 +469,7 @@ class UIWidget(QWidget):
             rule = rule.text()
             rule = rule.replace(" ", "")
             prod = rule.split(":")
-            rules[prod[0]].append([float(self.prod_percent[i].text()), prod[1]])
+            rules[prod[0]].append([float(self.prod_percent[i].text().split("%")[0])/100, prod[1]])
         return rules
 
     def close_event(self):
@@ -500,7 +508,7 @@ class UIWidget(QWidget):
             self.minuses = QPushButton("-", self)
             self.minuses.clicked.connect(self.less_prods)
             self.layout.addWidget(self.minuses, self.prods + 1, 10, 1, 1)
-            self.prod_percent[-1].setText("1")
+            self.prod_percent[-1].setText("100%")
 
     def less_prods(self):
         """ Removes textboxes for production rules when less are needed, minimum 1."""
@@ -550,7 +558,7 @@ class UIWidget(QWidget):
             self.less_prods()
         self.prod_rules_edit[-1].setText("")
         self.axiom_edit.setText("")
-        self.prod_percent[0].setText("1")
+        self.prod_percent[0].setText("100%")
         self.angle_edit.setText("")
         self.iters_edit.setText("")
 
@@ -647,6 +655,13 @@ class UIWidget(QWidget):
         self.iters_edit.setText(str(grammar["iterations"]))
         self.gen_sys()
 
+    def del_example(self, example, dim):
+        remove_saved_lsystem(example, dim)
+        print(example, " was deleted from disk")
+        self.reload_presets()
+
+        
+
     def reset_text_box_color(self):
         """resets the color of all textboxes"""
         for box in self.text_boxes:
